@@ -43,6 +43,7 @@ use constant MAKEARGS => "LIBTOOL=".LIBTOOL;
 
 __PACKAGE__->add_property( 'tarball' );
 __PACKAGE__->add_property( 'pkgconfig_module' );
+__PACKAGE__->add_property( 'pkgconfig_version' );
 
 sub new
 {
@@ -59,15 +60,16 @@ sub new
    my $self = $class->SUPER::new( %args );
 
    my $module = $self->pkgconfig_module;
+   my $version = $self->pkgconfig_version;
 
    $use_bundled = 1 if
-      !$use_bundled and system( "pkg-config", "--exists", $module ) != 0;
+      !$use_bundled and system( "pkg-config", $module, "--atleast-version", $version ) != 0;
 
    if( $use_bundled ) {
       print "Building bundled source\n";
    }
    else {
-      print "Detected $module from pkg-config\n";
+      print "Detected $module version >= $version from pkg-config\n";
    }
 
    $self->notes( use_bundled => $use_bundled );
